@@ -9,7 +9,7 @@ use Capture::Tiny 0.17 qw/capture_merged/;
 use Text::ParseWords qw/shellwords/;
 
 # ABSTRACT: Base classes for Alien:: modules
-our $VERSION = '0.79_01'; # TRIAL VERSION
+our $VERSION = '0.81_01'; # TRIAL VERSION
 $VERSION = eval $VERSION;
 
 
@@ -158,9 +158,13 @@ sub libs_static {
 
 sub version {
   my $self = shift;
-  my $version = $self->config('version');
-  chomp $version;
-  return $version;
+  return $self->runtime_prop
+    ? $self->runtime_prop->{version}
+    : do {
+      my $version = $self->config('version');
+      chomp $version;
+      $version;
+    };
 }
 
 
@@ -429,7 +433,7 @@ Alien::Base - Base classes for Alien:: modules
 
 =head1 VERSION
 
-version 0.79_01
+version 0.81_01
 
 =head1 SYNOPSIS
 
